@@ -14,6 +14,7 @@ def _compat_use_bootstrap_container(data, value):
     warnings.warn("The 'use_bootstrap_container' argument is obsoleted by "
                   "'bootstrap' and 'bootstrap_image'")
 
+
 @for_all_methods(bind_proxy)
 class ProjectProxy(BaseProxy):
 
@@ -70,7 +71,7 @@ class ProjectProxy(BaseProxy):
             auto_prune=True, use_bootstrap_container=None, devel_mode=False,
             delete_after_days=None, multilib=False, module_hotfixes=False,
             bootstrap=None, bootstrap_image=None, isolation=None,
-            fedora_review=None, appstream=True):
+            fedora_review=None, appstream=True, runtime_dependencies=None, packit_forge_projects_allowed=None):
         """
         Create a project
 
@@ -102,6 +103,11 @@ class ProjectProxy(BaseProxy):
         :param bool fedora_review: Run fedora-review tool for packages
                                    in this project
         :param bool appstream: Disable or enable generating the appstream metadata
+        :param string runtime_dependencies: List of external repositories
+            (== dependencies, specified as baseurls) that will be automatically
+            enabled together with this project repository.
+        :param list packit_forge_projects_allowed: List of forge projects that
+            will be allowed to build in the project via Packit
         :return: Munch
         """
         endpoint = "/project/add/{ownername}"
@@ -129,6 +135,8 @@ class ProjectProxy(BaseProxy):
             "module_hotfixes": module_hotfixes,
             "fedora_review": fedora_review,
             "appstream": appstream,
+            "runtime_dependencies": runtime_dependencies,
+            "packit_forge_projects_allowed": packit_forge_projects_allowed,
         }
 
         _compat_use_bootstrap_container(data, use_bootstrap_container)
@@ -147,7 +155,7 @@ class ProjectProxy(BaseProxy):
              auto_prune=None, use_bootstrap_container=None, devel_mode=None,
              delete_after_days=None, multilib=None, module_hotfixes=None,
              bootstrap=None, bootstrap_image=None, isolation=None,
-             fedora_review=None, appstream=None):
+             fedora_review=None, appstream=None, runtime_dependencies=None, packit_forge_projects_allowed=None):
         """
         Edit a project
 
@@ -178,6 +186,8 @@ class ProjectProxy(BaseProxy):
         :param bool fedora_review: Run fedora-review tool for packages
                                    in this project
         :param bool appstream: Disable or enable generating the appstream metadata
+        :param list packit_forge_projects_allowed: List of forge projects that
+            will be allowed to build in the project via Packit
         :return: Munch
         """
         endpoint = "/project/edit/{ownername}/{projectname}"
@@ -204,6 +214,8 @@ class ProjectProxy(BaseProxy):
             "module_hotfixes": module_hotfixes,
             "fedora_review": fedora_review,
             "appstream": appstream,
+            "runtime_dependencies": runtime_dependencies,
+            "packit_forge_projects_allowed": packit_forge_projects_allowed,
         }
 
         _compat_use_bootstrap_container(data, use_bootstrap_container)
